@@ -14,6 +14,7 @@ private:
     IloCplex *cplex;
     IloNumVarArray *variables;
     IloAlgorithm::Status optimstatus;
+    std::vector<int*> variableptrs;
     int _verbosity, var_counter;
     double cplextime;
     bool has_been_added;
@@ -36,6 +37,8 @@ public:
     void setThreadCount(const int nr_threads);
     void setVerbosity(const int degree);
     void setRandomSeed(const int seed);
+    void setWorkMem(const int mb);
+    int getWorkMem();
 
     bool is_opt();
     bool is_sat();
