@@ -530,6 +530,8 @@ Mistral2_Expression* Mistral2_LeqLex::add(Mistral2Solver *solver, bool top_level
 #ifdef _DEBUGWRAP
     std::cout << "add leqlex constraint" << std::endl;
 #endif
+
+    _solver = solver;
       
     for(int i = 0; i < _vars.size(); ++i)
       _vars.set_item(i, _vars.get_item(i)->add(solver, false));
@@ -569,6 +571,8 @@ Mistral2_Expression* Mistral2_LessLex::add(Mistral2Solver *solver, bool top_leve
 #ifdef _DEBUGWRAP
     std::cout << "add lesslex constraint" << std::endl;
 #endif
+
+    _solver = solver;
       
     for(int i = 0; i < _vars.size(); ++i)
       _vars.set_item(i, _vars.get_item(i)->add(solver, false));
@@ -666,10 +670,10 @@ Mistral2_Expression* Mistral2_Sum::add(Mistral2Solver *solver, bool top_level){
     
     int i, n=_vars.size();  
     Mistral::VarArray scope(n);
-    Mistral::Vector<int> w(n);
+    Mistral::Vector<int> w;
     bool weighted = false;
     bool boolean = true;
-
+    w.initialise(n, n);
 
     for(i=0; i<n; ++i) {
 
@@ -706,6 +710,56 @@ Mistral2_Expression* Mistral2_Sum::add(Mistral2Solver *solver, bool top_level){
   return this;
 }
 
+
+
+Mistral2_OrderedSum::Mistral2_OrderedSum(Mistral2ExpArray& vars, 
+			   const int l, const int u)
+  : Mistral2_Expression() 
+{
+#ifdef _DEBUGWRAP
+  std::cout << "creating ordered sum" << std::endl;
+#endif
+  _vars = vars;
+  _lb = l;
+  _ub = u;
+}
+
+
+Mistral2_OrderedSum::~Mistral2_OrderedSum(){
+#ifdef _DEBUGWRAP
+  std::cout << "delete ordered sum" << std::endl;
+#endif
+}
+
+
+Mistral2_Expression* Mistral2_OrderedSum::add(Mistral2Solver *solver, bool top_level){
+	if(!has_been_added()) {
+#ifdef _DEBUGWRAP
+		std::cout << "add ordered sum constraint" << std::endl;
+#endif
+		_solver = solver;
+    
+		// _v * _w + o = _x
+		// _v * _w - _x = -o 
+    
+		int i, n=_vars.size();  
+		Mistral::VarArray scope(n);
+
+		for(i=0; i<n; ++i) {
+			_vars.get_item(i)->add(_solver,false);
+			scope[i] = _vars.get_item(i)->_self;
+		}
+
+		_self = OSum(scope, _lb, _ub);
+    
+		if( top_level ) {
+			_solver->solver->add( _self );
+		} 
+	}
+
+  return this;
+}
+
 /**
  * Binary constraints
  */
@@ -939,6 +993,8 @@ Mistral2_Expression* Mistral2_or::add(Mistral2Solver *solver, bool top_level){
     std::cout << "add or predicate" << std::endl;
 #endif
 
+    _solver = solver;
+
     bool used = false;
     _vars[0]->add(_solver,false);
     if(_vars[1]) {
@@ -1373,7 +1429,8 @@ Mistral2Solver::Mistral2Solver()
 #endif
 
   solver = new Mistral::Solver();
-  solver->parameters.verbosity = 2; 
+  solver->parameters.verbosity = 2;
+  solver->consolidate();
 
   //_search_goal = NULL;
   
@@ -1833,3 +1890,10 @@ int Mistral2Solver::getRandomNumber()
 {
   return Mistral::randint(0xffffffff);
 }
+
+void Mistral2Solver::printPython()
+{
+	solver->consolidate();
+	solver->display(std::cout);
+}
+
